<template>
  <div id="name" style="width: 100%; height: 100%">
    <Echart 
      :options="options" 
      style="width: 100%; height: 100%"
      v-if="!loading"
    />
    <div v-else style="color: white; text-align: center; padding-top: 50px">
      数据加载中...
    </div>
    <div v-if="error" style="color: red; text-align: center; padding-top: 50px">
      数据加载失败: {{ error }}
    </div>
  </div>
</template>

<script>
import { GetProWeekTasks } from "@/api/http.js";
import * as echarts from 'echarts';

export default {
  data() {
    return {
      options: {},
      loading: false,
      error: null,
      timer: null
    };
  },
  created() {
    this.fetchData();
    this.startAutoRefresh();
  },
  beforeDestroy() {
    this.stopAutoRefresh();
  },
  methods: {
    initEmptyChart() {
      this.options = {
        tooltip: {
          trigger: 'axis',
          formatter: params => {
            let result = `${params[0].axisValue}<br>`;
            params.forEach(item => {
              result += `${item.marker} ${item.seriesName}: ${item.value}<br>`;
            });
            return result;
          }
        },
        legend: {
          right: '12%',
          bottom: '4%',
          textStyle: {
            color: '#fff',
            fontSize: '13'
          },
          itemGap: 20,
          itemWidth: 10,
          itemHeight: 10,
          icon: 'circle',
          data: ['成品入库', '成品出库', '空框回流', '成品回库']
        },
        grid: {
          left: '8%',
          top: '15%',
          bottom: '14%',
          width: '86%',
        },
        xAxis: {
          type: 'category',
          axisLine: {
            lineStyle: {
              color: '#132987'
            }
          },
          axisLabel: {
            textStyle: {
              color: '#FFF',
              fontSize: 12
            },
          },
          axisTick: {
            show: false
          },
          data: ['加载中...']
        },
        yAxis: {
          type: 'value',
          axisLabel: {
            textStyle: {
              color: '#fff',
              fontSize: 12,
            },
          },
          axisLine: {
            show: false,
          },
          axisTick: {
            show: false
          },
          splitLine: {
            show: true,
            lineStyle: {
              color: '#132987',
            }
          },
        },
        series: [
          { name: '成品入库', type: 'line', data: [] },
          { name: '成品出库', type: 'line', data: [] },
          { name: '空框回流', type: 'line', data: [] },
          { name: '成品回库', type: 'line', data: [] }
        ]
      };
    },
    async fetchData() {
       this.loading = true;
      this.error = null;
      
      try {
        console.log('正在请求数据...');
        const response = await GetProWeekTasks({});
        console.log('完整响应:', response); // 打印完整响应查看结构
        
        // 直接使用response作为数据（根据实际响应结构调整）
        if (!response || !response.dateRange || !response.dailyStatistics) {
          throw new Error('数据格式不正确');
        }
        
        this.updateChart(response); // 直接传入response，而非response.data
      } catch (error) {
        console.error('获取数据错误:', error);
        this.error = error.message;
        this.initEmptyChart();
      } finally {
        this.loading = false;
      }
    },
    updateChart(data) {
      
      
      const dates = data.dateRange;
      const stats = data.dailyStatistics;
      
      const seriesData = {
        '成品入库': [],
        '成品出库': [],
        '空框回流': [],
        '成品回库': []
      };
      
      // 根据实际数据格式调整字段名（小写开头）
      stats.forEach(day => {
        seriesData['成品入库'].push(day.inProduct || 0);
        seriesData['成品出库'].push(day.outProduct || 0);
        seriesData['空框回流'].push(day.emptyProductBack || 0);
        seriesData['成品回库'].push(day.inProductBack || 0);
      });
      
      this.options = {
        ...this.options,
        xAxis: {
          ...this.options.xAxis,
          data: dates
        },
        series: this.options.series.map(series => ({
          ...series,
          data: seriesData[series.name] || []
        }))
      };
    },
    startAutoRefresh() {
      this.stopAutoRefresh();
      this.timer = setInterval(() => {
        this.fetchData();
      }, this.$store.state.setting.echartsAutoTime || 10000);
    },
    stopAutoRefresh() {
      if (this.timer) clearInterval(this.timer);
    }
  }
};
</script>

<style lang='scss' scoped>
.user_Overview {
  li {
    flex: 1;

    p {
      text-align: center;
      height: 16px;
      font-size: 16px;
    }

    .user_Overview_nums {
      width: 100px;
      height: 100px;
      text-align: center;
      line-height: 100px;
      font-size: 22px;
      margin: 50px auto 30px;
      background-size: cover;
      background-position: center center;
      position: relative;

      &::before {
        content: "";
        position: absolute;
        width: 100%;
        height: 100%;
        top: 0;
        left: 0;
      }

      &.bgdonghua::before {
        animation: rotating 14s linear infinite;
      }
    }

    .allnum {
      // background-image: url("../../assets/img/left_top_lan.png");
      &::before {
        background-image: url("../../assets/img/left_top_lan.png");
      }
    }

    .online {
      &::before {
        background-image: url("../../assets/img/left_top_lv.png");
      }
    }

    .offline {
      &::before {
        background-image: url("../../assets/img/left_top_huang.png");
      }
    }

    .laramnum {
      &::before {
        background-image: url("../../assets/img/left_top_hong.png");
      }
    }
  }
}
</style>